@@ -86,7 +86,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -163,6 +163,12 @@
 #else
 #  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text)
 #endif
+
+#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_97(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KWIDGETSADDONS_DEPRECATED_VERSION_5(minor, text)      KWIDGETSADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -228,7 +234,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -238,7 +244,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -305,6 +311,12 @@
 #else
 #  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text)
 #endif
+
+#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_97(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KWIDGETSADDONS_DEPRECATED_VERSION_5(minor, text)      KWIDGETSADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
